# xipaprm.def --- parameters for XIPA font families.
# 
# 1996/06/24 first version
# 2001/12/29 Values modified esp. for xipa10.
#            bs10 (Bold Slanted), sb10 (Sans Serif Bold),
#            si10 (Sans Serif Slanted) added.
# 2003/01/01 values of stem and jut modified.
#
# The basic idea of this file is borrowed from dc fonts. But this file
# is processed by awk, not by a Metafont macro.
#
# NB: The parameter `variant_g' is omitted, and sc.u, sc.letter_fit added.
#     For TT family of fonts, sc.u# shuold be equal to u# !!!
#     p: x/36pt#, P: xpt#, n: x, SC12: sind 12 / cosd 12, SQ2: sqrt 2
#
#                     10  sl10    b10   bs10   ss10   si10   sb10
#                                                                
p u                   18    18     20     20     20     20     22
p width_adj            0     0     10     10     15     15     15
p serif_fit            0     0      0      0     -7     -7     -9
p cap_serif_fit        5     5      6      6    -10    -10    -11
p letter_fit           0     0      0      0      0      0      0
p body_height        270   270    270    270    270    270    270
p asc_height       245.5 245.5  245.5  245.5    260    260    260
p cap_height       240.5 240.5  242.1  242.1    260    260    260
p fig_height         232   232    232    232    236    236    236
p x_height           162   162 165.96 165.96 188.28 188.28 191.52
p math_axis           90    90     90     90     90     90     90
p bar_height         106   106  97.73  97.73     95     95     95
p comma_depth       50.7  50.7     51     51     50     50     50
p desc_depth        77.9  77.9  73.26  73.26   75.8   75.8   75.8
p crisp                0     0      0      0      0      0      0
p tiny                 8     8     13     13      0      0      0
p fine                 7     7     10     10      0      0      0
p thin_join            8     8     10     10     17     17     20
p hair                 9     9     17     17     30     30     49
p stem                30    30     47     47     30     30     49
p curve               34    34     52     52     30     30     49
p ess                 30    30     49     49     30     30     43
p flare               27    27     39     39     27     27     40
p dot_size            32    32     52     52     30     30     47
p cap_hair            11    11     19     19     30     30     49
p cap_stem            36    36     57     57     32     32     53
p cap_curve           42    42     61     61     32     32     53
p cap_ess             39    39     58     58     32     32     51
P rule_thickness      .4    .4     .6     .6     .4     .4  30/36
p dish                 0     0      0      0      0      0      0
p bracket             22    22     22     22      0      0      0
p jut                 26    26     25     25      0      0      0
p cap_jut             37    37     34     34      0      0      0
p beak_jut            10    10     11     11      0      0      0
p beak                70    70     70     70     .5     .5    1.5
p vair                 9     9     13     13     22     22     26
P notch_cut           10    10     10     10  18/36  18/36  49/36
p bar                 11    11     17     17     21     21     26
p slab               1.5   1.5    2.2    2.2     21     21     36
p cap_bar             11    11     17     17     22     22     34
p cap_band            11    11     17     17     20     20     31
P cap_notch_cut       10    10     10     10  25/36  25/36  45/36
p serif_drop          15    15      0      0      2      2      0
p stem_corr            1     1      2      2      1      1      1
p vair_corr            1     1    1.5    1.5      1      1      2
p apex_corr            0     0      0      0      5      5     18
p o                    6     6      4      4      6      6      8
p apex_o               6     6      3      3      0      0      0
n slant                0   1/6      0    1/6      0    1/6      0
n fudge                1     1      1      1    .96    .96    .88
n math_spread          0     0     .5     .5      0      0     .5
n superness        1/SQ2 1/SQ2   8/11   8/11  1/SQ2  1/SQ2    .75
n superpull          1/6   1/6    1/8    1/8   1/20   1/20   1/18
n beak_darkness    11/30 11/30     .4     .4      0      0      0
n ligs                 2     2      2      2      2      2      2
n square_dots      false false  false  false   true   true   true
n hefty            false false  false  false   true   true   true
n serifs            true  true   true   true  false  false  false
n monospace        false false  false  false  false  false  false
n low_asterisk     false false  false  false  false  false  false
n math_fitting     false false  false  false  false  false  false
p sc.u                14    14  15.56  15.56  15.56  15.56  17.11
p sc.letter_fit      2.4   2.4    2.4    2.4    2.4    2.4    2.4
