% ts3enc.def: TIPA Additional symbols
% Copyright 2002 FUKUI Rei
%
% This program may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.2
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.2 or later is part of all distributions of LaTeX 
% version 1999/12/01 or later.
%
% This program consists of all files listed in Manifest.txt.
%
% Version 1.0 2001/12/31
%
\ProvidesFile{ts3enc.def}[2001/12/31 TS3 encoding]
\DeclareFontEncoding{TS3}{}{}

\DeclareTextSymbol\textrthooklong{TS3}{1}
\DeclareTextSymbol\textpalhooklong{TS3}{2}
\DeclareTextSymbol\textpalhookvar{TS3}{3}
\DeclareTextSymbol\textrectangle{TS3}{4}
\DeclareTextSymbol\textspleftarrow{TS3}{5}
\DeclareTextSymbol\textretractingvar{TS3}{6}
\DeclareTextSymbol\textdownfullarrow{TS3}{7}
\DeclareTextSymbol\textupfullarrow{TS3}{8}
\DeclareTextSymbol\textsubrightarrow{TS3}{9}
\DeclareTextSymbol\textsubdoublearrow{TS3}{10}

\DeclareTextSymbol\textrhooka{TS3}{32}
\DeclareTextSymbol\textinvscripta{TS3}{33}
\DeclareTextSymbol\textaolig{TS3}{34}
\DeclareTextSymbol\textlhookfour{TS3}{35}
\DeclareTextSymbol\textstretchcvar{TS3}{36}
\DeclareTextSymbol\textctstretchc{TS3}{37}
\DeclareTextSymbol\textctstretchcvar{TS3}{38}
\DeclareTextSymbol\textfrhookd{TS3}{39}
\DeclareTextSymbol\textfrhookdvar{TS3}{40}
\DeclareTextSymbol\textdblig{TS3}{41}
\DeclareTextSymbol\textrhooke{TS3}{42}
\DeclareTextSymbol\textrhookepsilon{TS3}{43}
\DeclareTextSymbol\textgrgamma{TS3}{44}
\DeclareTextSymbol\textfrtailgamma{TS3}{45}
\DeclareTextSymbol\textbktailgamma{TS3}{46}
\DeclareTextSymbol\textrtailhth{TS3}{47}
\DeclareTextSymbol\textheng{TS3}{48}
\DeclareTextSymbol\textlhti{TS3}{49}
\DeclareTextSymbol\textctjvar{TS3}{50}
\DeclareTextSymbol\texthtbardotlessjvar{TS3}{51}
\DeclareTextSymbol\texthmlig{TS3}{52}
\DeclareTextSymbol\textfrbarn{TS3}{53}
\DeclareTextSymbol\textnrleg{TS3}{54}
\DeclareTextSymbol\textfemale{TS3}{55}
\DeclareTextSymbol\textuncrfemale{TS3}{56}
\DeclareTextSymbol\textObullseye{TS3}{57}
\DeclareTextSymbol\textrhookopeno{TS3}{58}
\DeclareTextSymbol\textinvomega{TS3}{59}
\DeclareTextSymbol\textlhookp{TS3}{60}
\DeclareTextSymbol\textqplig{TS3}{61}
\DeclareTextSymbol\textlooptoprevesh{TS3}{62}
\DeclareTextSymbol\textfrhookt{TS3}{63}
\DeclareTextSymbol\textctturnt{TS3}{64}
\DeclareTextSymbol\textturntwo{TS3}{65}
\DeclareTextSymbol\textbenttailyogh{TS3}{66}
\DeclareTextSymbol\textturnthree{TS3}{67}
\DeclareTextSymbol\textctinvglotstop{TS3}{68}
\DeclareTextSymbol\textturnglotstop{TS3}{69}
\DeclareTextSymbol\textpipevar{TS3}{70}
\DeclareTextSymbol\textdoublepipevar{TS3}{71}
\DeclareTextSymbol\textdoublebarpipevar{TS3}{72}
\DeclareTextSymbol\textlfishhookrlig{TS3}{73}

\DeclareTextSymbol\textthornvari{TS3}{80}
\DeclareTextSymbol\textthornvarii{TS3}{81}
\DeclareTextSymbol\textthornvariii{TS3}{82}
\DeclareTextSymbol\textthornvariv{TS3}{83}
\DeclareTextSymbol\textglotstopvari{TS3}{84}
\DeclareTextSymbol\textglotstopvarii{TS3}{85}
\DeclareTextSymbol\textglotstopvariii{TS3}{86}

\DeclareTextSymbol\textinvsca{TS3}{112}
\DeclareTextSymbol\textscaolig{TS3}{113}
\DeclareTextSymbol\textscdelta{TS3}{114}
\DeclareTextSymbol\textscf{TS3}{115}
\DeclareTextSymbol\textsck{TS3}{116}
\DeclareTextSymbol\textturnsck{TS3}{117}
\DeclareTextSymbol\textrevscl{TS3}{118}
\DeclareTextSymbol\textscm{TS3}{119}
\DeclareTextSymbol\textscp{TS3}{120}
\DeclareTextSymbol\textscq{TS3}{121}
\DeclareTextSymbol\textrevscr{TS3}{122}
\DeclareTextSymbol\textturnscu{TS3}{123}

\endinput
